import importlib.resources as pkg_resources
import pint

# Edit constants template to stop using h to represent planck_constant
# See https://github.com/hgrecco/pint/issues/719#issuecomment-998872301
# ---------------------------------------------------------------------
constants_template = pkg_resources.read_text(pint, 'constants_en.txt').replace("= h  ", "     ").replace(" h ", " planck_constant ")

# Edit units template to use h to represent hour instead of planck_constant
units_template = pkg_resources.read_text(pint, 'default_en.txt').replace("@import constants_en.txt", "").replace(" h ", " planck_constant ").replace("hour = 60 * minute = hr", "hour = 60 * minute = h = hr")

# Join templates as iterable object
full_template = constants_template.split("\n") + units_template.split("\n")

# Set up UnitRegistry with abbreviated scientific format
ureg = pint.UnitRegistry(full_template)
ureg.default_format = "~P"  # short pretty
# ---------------------------------------------------------------------

# Add new definitions / aliases
ureg.define('cubic_feet_per_minute = cu_ft / min = cfm')
ureg.define('in_H2O = inch_H2O_39F')
ureg.define('ton_ref = ton_of_refrigeration')

# Public functions
def fr_u(value, from_units):
  '''Convert a value from given units to base SI units'''
  return ureg.Quantity(value, from_units).to_base_units().magnitude

def to_u(value, to_units):
  '''Convert from base SI units to any other units'''
  base_units = ureg.Quantity(value, to_units).to_base_units().units
  return ureg.Quantity(value, base_units).to(to_units).magnitude

def convert(value, from_units, to_units):
  '''Convert from any units to another units of the same dimension'''
  return ureg.Quantity(value, from_units).to(to_units).magnitude




# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['koozie']

package_data = \
{'': ['*']}

install_requires = \
['pint>=0.18,<0.19']

setup_kwargs = {
    'name': 'koozie',
    'version': '1.0.0',
    'description': 'A light-weight wrapper around pint.',
    'long_description': "[![Release](https://img.shields.io/pypi/v/koozie.svg)](https://pypi.python.org/pypi/koozie)\n\n[![Test](https://github.com/bigladder/koozie/actions/workflows/test.yaml/badge.svg)](https://github.com/bigladder/koozie/actions/workflows/test.yaml)\n\nkoozie\n======\n\n*koozie* is a light-weight wrapper around [*pint*](https://pint.readthedocs.io/en/stable/). The intent is to provide much of the functionality without worrying about the setup. It uses quantities internally, but its functions only return floats. This approach reflects the opinion that all calculations should be performed in Standard base SI units, and any conversions can happen via pre- or post-processing for usability. This minimizes additional operations in performance critical code.\n\n*koozie* also defines a few convenient aliases for different units. See the [source code](https://github.com/bigladder/koozie/blob/master/koozie/koozie.py) for details. A list of other available units is defined in [pint's default units definition file](https://github.com/hgrecco/pint/blob/master/pint/default_en.txt).\n\nThere are three public functions in *koozie*:\n\n- `fr_u(value, from_units)`: Convert a value from given units to base SI units\n- `to_u(value, to_units)`: Convert a value from base SI units to given units\n- `convert(value, from_units, to_units)`: Convert from any units to another units of the same dimension\n\nExample usage can be found in the [test file](https://github.com/bigladder/koozie/blob/master/test/test_koozie.py).\n",
    'author': 'Big Ladder Software',
    'author_email': 'None',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/bigladder/koozie',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
